%--------------------------------------------------------
% Carlos Cabral 2003 - Dep.UA

% Program to analyse Laser data from Outdoor Experience 3.03.2003
% -------------------------------------------------------



function varargout = experienc(varargin)
% EXPERIENC M-file for experienc.fig
%      EXPERIENC, by itself, creates a new EXPERIENC or raises the existing
%      singleton*.
%
%      H = EXPERIENC returns the handle to a new EXPERIENC or the handle to
%      the existing singleton*.
%
%      EXPERIENC('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in EXPERIENC.M with the given input arguments.
%
%      EXPERIENC('Property','Value',...) creates a new EXPERIENC or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before experienc_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to experienc_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help experienc

% Last Modified by GUIDE v2.5 09-Apr-2003 17:53:36

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @experienc_OpeningFcn, ...
                   'gui_OutputFcn',  @experienc_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT
%//////////////////////////////////////////////////////////////////////////

% --- Executes just before experienc is made visible.
function experienc_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to experienc (see VARARGIN)


Ldata01
handles.Ldata=a;
guidata(hObject,handles)

% Choose default command line output for experienc
handles.output = hObject;
% Update handles structure
guidata(hObject, handles);
% UIWAIT makes experienc wait for user response (see UIRESUME)
% uiwait(handles.figure1);

% --- Outputs from this function are returned to the command line.
function varargout = experienc_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

% --- Executes during object creation, after setting all properties.
function edit1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end

function edit1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1 as text
%        str2double(get(hObject,'String')) returns contents of edit1 as a double

% Get user input from GUI
f1 = str2double(get(handles.edit1,'String'));
i=f1;
laser_plot(i,handles.Ldata);
time_s=handles.Ldata(i,1:3);
time_temp=(time_s(3)+time_s(2)*60-(50+30*60));
time_(1)=fix(time_temp/60);
time_(2)=mod(time_temp,60);

time_temp=(time_s(3)+time_s(2)*60-(50+30*60))-32;
if time_temp < 0
    time_v(1)=0;
    time_v(2)=0;
else
    time_v(1)=fix(time_temp/60);
    time_v(2)=mod(time_temp,60);
end

set(handles.edit2,'String',num2str(time_s));
set(handles.edit3,'String',num2str(time_));
set(handles.edit4,'String',num2str(time_v));

handles.current_data = i;
guidata(hObject,handles)
 
    % % --- Executes on button press in pushbutton1.
    % function pushbutton1_Callback(hObject, eventdata, handles)
    % % hObject    handle to pushbutton1 (see GCBO)
    % % eventdata  reserved - to be defined in a future version of MATLAB
    % % handles    structure with handles and user data (see GUIDATA)
    % 
    % % Get user input from GUI
    % f1 = str2double(get(handles.edit1,'String'));
    % i=f1;
    % laser_plot(i,handles.Ldata);
    % time_s=handles.Ldata(i,1:3);
    % time_temp=(time_s(3)+time_s(2)*60-(50+30*60));
    % time_(1)=fix(time_temp/60);
    % time_(2)=mod(time_temp,60);
    % 
    % time_temp=(time_s(3)+time_s(2)*60-(50+30*60))-32;
    % if time_temp < 0
    %     time_v(1)=0;
    %     time_v(2)=0;
    % else
    %     time_v(1)=fix(time_temp/60);
    %     time_v(2)=mod(time_temp,60);
    % end
    % 
    % set(handles.edit2,'String',num2str(time_s));
    % set(handles.edit3,'String',num2str(time_));
    % set(handles.edit4,'String',num2str(time_v));
    % 
    % handles.current_data = i;
    % guidata(hObject,handles)

% --- Executes on button press in pushbutton4.
function pushbutton4_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

i = handles.current_data;
i=i+1;

laser_plot(i,handles.Ldata);
time_s=handles.Ldata(i,1:3);
time_temp=(time_s(3)+time_s(2)*60-(50+30*60));
time_(1)=fix(time_temp/60);
time_(2)=mod(time_temp,60);

time_temp=(time_s(3)+time_s(2)*60-(50+30*60))-32;
if time_temp < 0
    time_v(1)=0;
    time_v(2)=0;
else
    time_v(1)=fix(time_temp/60);
    time_v(2)=mod(time_temp,60);
end

set(handles.edit2,'String',num2str(time_s));
set(handles.edit3,'String',num2str(time_));
set(handles.edit4,'String',num2str(time_v));

handles.current_data = i;
guidata(hObject,handles)

set(handles.edit1,'String',num2str(handles.current_data));

% --- Executes on button press in pushbutton5.
function pushbutton5_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

i = handles.current_data;
i=i-1;

laser_plot(i,handles.Ldata);
time_s=handles.Ldata(i,1:3);
time_temp=(time_s(3)+time_s(2)*60-(50+30*60));
time_(1)=fix(time_temp/60);
time_(2)=mod(time_temp,60);

time_temp=(time_s(3)+time_s(2)*60-(50+30*60))-32;
if time_temp < 0
    time_v(1)=0;
    time_v(2)=0;
else
    time_v(1)=fix(time_temp/60);
    time_v(2)=mod(time_temp,60);
end
set(handles.edit2,'String',num2str(time_s));
set(handles.edit3,'String',num2str(time_));
set(handles.edit4,'String',num2str(time_v));

handles.current_data = i;
guidata(hObject,handles)

set(handles.edit1,'String',num2str(handles.current_data));
%//////////////////////////////////////////////////////////////////////////

% --- Executes during object creation, after setting all properties.
function edit2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end

function edit2_Callback(hObject, eventdata, handles)
% hObject    handle to edit2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit2 as text
%        str2double(get(hObject,'String')) returns contents of edit2 as a double


% --- Executes during object creation, after setting all properties.
function edit3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end

function edit3_Callback(hObject, eventdata, handles)
% hObject    handle to edit3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3 as text
%        str2double(get(hObject,'String')) returns contents of edit3 as a double


% --- Executes during object creation, after setting all properties.
function edit4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end

function edit4_Callback(hObject, eventdata, handles)
% hObject    handle to edit4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit4 as text
%        str2double(get(hObject,'String')) returns contents of edit4 as a double

